Learn R Programming

starm (version 0.1.0)

covplant: Covariate data

Description

covplant is the dataset of the spatial covariate of the plantillness dataset. Each column can be used as a covariate along the plantillness dataset in the estima function. Each row of a selected covariate matches a point of the plantillness dataset, that's why there is no coordinates in the covplant dataset.

Usage

covplant

Arguments

Format

An object of class data.frame with 2366 rows and 3 columns.

Details

  • $v1 spatial covariate

  • $v2 spatial covariate

  • $v3 spatial covariate