covplant is the dataset of the spatial covariate of the plantillness dataset. Each column can be used as a covariate along the plantillness dataset in the estima function. Each row of a selected covariate matches a point of the plantillness dataset, that's why there is no coordinates in the covplant dataset.